@@ -706,7 +706,7 @@ def rasterize(feature, grid, id_column=None,
     elif isinstance(feature, pd.DataFrame):
         df = feature.copy()
         df = gpd.GeoDataFrame(df, crs=crs)
-    elif isinstance(feature, collections.Iterable):
+    elif isinstance(feature, collections.abc.Iterable):
         # list of shapefiles
         if isinstance(feature[0], str) or isinstance(feature[0], Path):
             # use shp2df to read multiple shapefiles
@@ -716,7 +716,7 @@ def rasterize(feature, grid, id_column=None,
         else:
             df = pd.DataFrame({'geometry': feature})
             df = gpd.GeoDataFrame(df, crs=crs)
-    elif not isinstance(feature, collections.Iterable):
+    elif not isinstance(feature, collections.abc.Iterable):
         df = pd.DataFrame({'geometry': [feature]})
         df = gpd.GeoDataFrame(df, crs=crs)
     else:
@@ -747,7 +747,7 @@ def rasterize(feature, grid, id_column=None,
         numbers = list(range(1, len(df)+1))
     # if IDs are strings, get a number for each one
     # pd.DataFrame.unique() generally preserves order
-    elif df[id_column].dtype == np.object:
+    elif df[id_column].dtype == object:
         unique_values = df[id_column].unique()
         values = dict(zip(unique_values, range(1, len(unique_values) + 1)))
         numbers = [values[n] for n in df[id_column]]
@@ -822,7 +822,7 @@ def setup_structured_grid(xoff=None, yoff=None, xul=None, yul=None,
                 delc_grid = delc_grid[0]
             else:
                 regular = False
-    if parent_model is not None:
+    if parent_model is not None and snap_to_parent:
         to_grid_units_parent = convert_length_units(get_model_length_units(parent_model), grid_units)
         # parent model grid spacing in meters
         parent_delr_grid = np.round(parent_model.dis.delr.array[0] * to_grid_units_parent, 4)
@@ -880,17 +880,17 @@ def setup_structured_grid(xoff=None, yoff=None, xul=None, yul=None,
             except:
                 features_crs = get_proj_str(features_shapefile)
                 reproject_filter = True
-            filter = None
+            bbox_filter = None
             if parent_model is not None:
                 if reproject_filter:
-                    filter = project(parent_model.modelgrid.bbox,
+                    bbox_filter = project(parent_model.modelgrid.bbox,
                                      parent_model.modelgrid.crs, features_crs).bounds
                 else:
-                    filter = parent_model.modelgrid.bbox.bounds
+                    bbox_filter = parent_model.modelgrid.bbox.bounds
             shp2df_kwargs = {'dest_crs': crs}
             shp2df_kwargs = get_input_arguments(shp2df_kwargs, shp2df)
             df = shp2df(features_shapefile,
-                        filter=filter, **shp2df_kwargs)
+                        filter=bbox_filter, **shp2df_kwargs)
 
             # optionally subset shapefile data to specified features
             if id_column is not None and include_ids is not None:
