@@ -784,7 +784,7 @@ class MF6model(MFsetupMixin, mf6.ModflowGwf):
         """
         # prior to writing output
         # remove any BCs in inactive cells
-        pckgs = ['CHD']
+        pckgs = ['chd', 'drn', 'ghb', 'riv', 'wel']
         for pckg in pckgs:
             package_instance = getattr(self, pckg.lower(), None)
             if package_instance is not None:
@@ -835,7 +835,7 @@ class MF6model(MFsetupMixin, mf6.ModflowGwf):
         # add version info to file headers
         files = [self.namefile]
         files += [p.filename for p in self.packagelist]
-        files += [p.filename for k, p in self.simulation.package_key_dict.items()]
+        files += [p[0].filename for k, p in self.simulation.package_key_dict.items()]
         for f in files:
             add_version_to_fileheader(f, model_info=self.header)
 
