@@ -11,7 +11,6 @@ def test_rtree():
 def test_dtypeisfloat():
 
     assert dtypeisfloat(float)
-    assert dtypeisfloat(np.float)
     assert dtypeisfloat(np.float32)
     assert dtypeisfloat(np.float64)
     assert not dtypeisfloat(int)
@@ -20,7 +19,6 @@ def test_dtypeisfloat():
 
 def test_dtypeisinteger():
     assert dtypeisinteger(int)
-    assert dtypeisinteger(np.int)
     assert dtypeisinteger(np.int32)
     assert dtypeisinteger(np.int64)
     assert not dtypeisinteger(float)
